@@ -1,4 +1,5 @@
 import feedparser
+from pathlib import Path
 from rich import print
 import os.path
 
@@ -10,9 +11,7 @@ def get_id():
     id_file = '.dailydevid.txt'
     bookmark_id = ""
     if os.path.isfile(id_file):
-        with open(id_file, 'r') as file:
-            bookmark_id = file.readlines()
-        bookmark_id = bookmark_id[0]
+        bookmark_id = Path(id_file).read_text()
 
     if not bookmark_id:
         print("[green]Enter your-daily-dev bookmark feed url: ", end="")
@@ -21,7 +20,8 @@ def get_id():
 
     return bookmark_id
 
-def get_bookmarks():
+
+def get_bookmarks_list():
 
     daily_id = get_id()
     id_file = '.dailydevid.txt'
@@ -33,11 +33,15 @@ def get_bookmarks():
         if 'feed' in feed:
             with open(id_file, 'w') as file:
                 file.write(daily_id)
-        name = feed.feed.title
+
+        bookmarks = feed.entries
+        return bookmarks
+
+def get_bookmarks():
 
         print(f"[red]{name}")
 
-        bookmarks = feed.entries
+        bookmarks = get_bookmarks_list()
 
         for bookmark in bookmarks:
             link = bookmark.link.split("?utm_source")[0].strip()
@@ -55,3 +59,4 @@ def get_bookmarks():
         print("[red]Please input a valid User ID!")
     input()
 
+
